@@ -1,10 +1,6 @@
-__version__ = "1.0.3"
-
-import pytest
+__version__ = "2.0.0"
 
 from pytest_reraise import reraise
 from pytest_reraise.reraise import Reraise
 
 __all__ = ["reraise", "Reraise", "__version__"]
-
-pytest.register_assert_rewrite("pytest_reraise.reraise")
